@@ -117,8 +117,9 @@ void dd_DDMain(dd_ConePtr cone)
       set_addelem(cone->WeaklyAddedHalfspaces, hh);
     }
     if (!cone->PreOrderedRun){
-      for (itemp=1; cone->OrderVector[itemp]!=hh; itemp++);
-        otemp=cone->OrderVector[cone->Iteration];
+      for (itemp=1; cone->OrderVector[itemp]!=hh; itemp++)
+        ; /* semicolon on line by itself to silence clang warning */ 
+      otemp=cone->OrderVector[cone->Iteration];
       cone->OrderVector[cone->Iteration]=hh;
         /* store the dynamic ordering in ordervec */
       cone->OrderVector[itemp]=otemp;
